summaryrefslogtreecommitdiff
path: root/drivers
diff options
context:
space:
mode:
Diffstat (limited to 'drivers')
-rw-r--r--drivers/cxl/Makefile4
-rw-r--r--drivers/cxl/core.c (renamed from drivers/cxl/bus.c)15
2 files changed, 10 insertions, 9 deletions
diff --git a/drivers/cxl/Makefile b/drivers/cxl/Makefile
index a314a1891f4d..3808e39dd31f 100644
--- a/drivers/cxl/Makefile
+++ b/drivers/cxl/Makefile
@@ -1,7 +1,7 @@
# SPDX-License-Identifier: GPL-2.0
-obj-$(CONFIG_CXL_BUS) += cxl_bus.o
+obj-$(CONFIG_CXL_BUS) += cxl_core.o
obj-$(CONFIG_CXL_MEM) += cxl_mem.o
ccflags-y += -DDEFAULT_SYMBOL_NAMESPACE=CXL
-cxl_bus-y := bus.o
+cxl_core-y := core.o
cxl_mem-y := mem.o
diff --git a/drivers/cxl/bus.c b/drivers/cxl/core.c
index 58f74796d525..7f8d2034038a 100644
--- a/drivers/cxl/bus.c
+++ b/drivers/cxl/core.c
@@ -4,26 +4,27 @@
#include <linux/module.h>
/**
* DOC: cxl bus
*
* The CXL bus provides namespace for control devices and a rendezvous
* point for cross-device interleave coordination.
*/
+
struct bus_type cxl_bus_type = {
.name = "cxl",
};
EXPORT_SYMBOL_GPL(cxl_bus_type);
-static __init int cxl_bus_init(void)
+static __init int cxl_core_init(void)
{
return bus_register(&cxl_bus_type);
}
-static void cxl_bus_exit(void)
+static void cxl_core_exit(void)
{
bus_unregister(&cxl_bus_type);
}
-module_init(cxl_bus_init);
-module_exit(cxl_bus_exit);
+module_init(cxl_core_init);
+module_exit(cxl_core_exit);
MODULE_LICENSE("GPL v2");
@@ -4,26 +4,27 @@
#include <linux/module.h>
/**
- * DOC: cxl bus
+ * DOC: cxl core
*
@@ -4,26 +4,27 @@
*
- * The CXL bus provides namespace for control devices and a rendezvous
- * point for cross-device interleave coordination.
+ * The CXL core provides a sysfs hierarchy for control devices and a rendezvous
+ * point for cross-device interleave coordination through cxl ports.
*/